@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.22 2004/06/26 18:28:44 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.25.4.1 2004/10/10 16:18:26 marco Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -50,42 +50,42 @@ struct _EphyEmbedSingleIface
 
 	/* Methods */
 
-	void	 (* open_window)	 (EphyEmbedSingle *single,
-					  EphyEmbed *parent,
-					  const char *address,
-					  const char *features);
-	void	 (* clear_cache)         (EphyEmbedSingle *shell);
-	void	 (* clear_auth_cache)	 (EphyEmbedSingle *shell);
-	void	 (* set_offline_mode)    (EphyEmbedSingle *shell,
-					  gboolean offline);
-	gboolean (* get_offline_mode)	 (EphyEmbedSingle *single);
-	void	 (* load_proxy_autoconf) (EphyEmbedSingle *shell,
-					  const char* url);
-	GList *	 (* get_font_list)	 (EphyEmbedSingle *shell,
-					  const char *langGroup);
-};
-
-GType	 ephy_embed_single_get_type		(void);
-
-void	 ephy_embed_single_open_window		(EphyEmbedSingle *single,
+	GtkWidget *	  (* open_window)	(EphyEmbedSingle *single,
 						 EphyEmbed *parent,
 						 const char *address,
+						 const char *name,
 						 const char *features);
-
-void	 ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
-
-void	 ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
-
-void	 ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
+	void		  (* clear_cache)	(EphyEmbedSingle *shell);
+	void		  (* clear_auth_cache)	(EphyEmbedSingle *shell);
+	void		  (* set_offline_mode)	(EphyEmbedSingle *shell,
 						 gboolean offline);
+	gboolean	  (* get_offline_mode)	(EphyEmbedSingle *single);
+	GList *		  (* get_font_list)	(EphyEmbedSingle *shell,
+						 const char *langGroup);
+	GList *		  (* get_printer_list)	(EphyEmbedSingle *shell);
+};
 
-gboolean ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
+GType		ephy_embed_single_get_type		(void);
 
-void	 ephy_embed_single_load_proxy_autoconf	(EphyEmbedSingle *single,
-						 const char* url);
+GtkWidget      *ephy_embed_single_open_window		(EphyEmbedSingle *single,
+							 EphyEmbed *parent,
+							 const char *address,
+							 const char *name,
+							 const char *features);
 
-GList	*ephy_embed_single_get_font_list		(EphyEmbedSingle *single,
-						 const char *lang_group);
+void		ephy_embed_single_clear_cache		(EphyEmbedSingle *single);
+
+void		ephy_embed_single_clear_auth_cache	(EphyEmbedSingle *single);
+
+void		ephy_embed_single_set_offline_mode	(EphyEmbedSingle *single,
+							 gboolean offline);
+
+gboolean	ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
+
+GList		*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
+							 const char *lang_group);
+
+GList		*ephy_embed_single_get_printer_list	(EphyEmbedSingle *single);
 
 G_END_DECLS
 
