@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-cache.c,v 1.34 2004/04/09 16:59:36 adamh Exp $
+ *  $Id: ephy-favicon-cache.c,v 1.34.10.1 2004/09/18 08:11:11 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -379,7 +379,8 @@ ephy_favicon_cache_download (EphyFaviconCache *cache,
 		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
 
 	ephy_embed_persist_set_dest (persist, dest);
-	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_NO_VIEW);
+	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_NO_VIEW |
+					       EMBED_PERSIST_DO_CONVERSION);
 	ephy_embed_persist_set_max_size (persist, 100 * 1024);
 	ephy_embed_persist_set_source (persist, favicon_url);
 
