@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-password-manager.c,v 1.3 2004/02/20 11:49:42 chpe Exp $
+ *  $Id: ephy-password-manager.c,v 1.4 2004/08/21 16:33:58 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -106,6 +106,8 @@ ephy_password_info_free (EphyPasswordInfo *info)
 
 /* EphyPasswordManager */
 
+static void ephy_password_manager_base_init (gpointer g_class);
+
 GType
 ephy_password_manager_get_type (void)
 {
@@ -116,7 +118,7 @@ ephy_password_manager_get_type (void)
 		static const GTypeInfo our_info =
 		{
 			sizeof (EphyPasswordManagerIface),
-			NULL,
+			ephy_password_manager_base_init,
 			NULL,
 		};
 		
@@ -129,6 +131,33 @@ ephy_password_manager_get_type (void)
 	return type;
 }
 
+static void
+ephy_password_manager_base_init (gpointer g_class)
+{
+	static gboolean initialised = FALSE;
+
+	if (initialised == FALSE)
+	{
+	/**
+	 * EphyPasswordManager::changed
+	 * @manager: the #EphyPermissionManager
+	 *
+	 * The ::passwords-changed signal is emitted when the list of passwords
+	 * has changed.
+	 */
+	g_signal_new ("passwords-changed",
+		      EPHY_TYPE_PASSWORD_MANAGER,
+		      G_SIGNAL_RUN_FIRST,
+		      G_STRUCT_OFFSET (EphyPasswordManagerIface, changed),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__VOID,
+		      G_TYPE_NONE,
+		      0);
+
+	initialised = TRUE;
+	}
+}
+
 /**
  * ephy_password_manager_add:
  * @manager: the #EphyPasswordManager
