@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.19.8.3 2004/11/14 11:40:01 chpe Exp $
+ *  $Id: ContentHandler.h,v 1.19.8.4 2004/11/16 22:38:52 chpe Exp $
  */
 
 #ifndef __ContentHandler_h
@@ -67,14 +67,11 @@ class GContentHandler : public nsIHelperAppLauncherDialog
   private:
 
 	NS_METHOD Init ();
-	NS_METHOD LaunchHelperApp ();
 
 	NS_METHOD MIMEConfirmAction ();
 	NS_METHOD MIMEDoAction ();
 
 	nsCOMPtr<nsIHelperAppLauncher> mLauncher;
-	nsCOMPtr<nsIURI> mUri;
-	nsCOMPtr<nsIFile> mTempFile;
 	nsCOMPtr<nsISupports> mContext;
 
 	PRBool mAppSupportScheme;
@@ -83,7 +80,6 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	EphyMimePermission mPermission;
 
 	nsEmbedCString mUrl;
-	nsEmbedCString mScheme;
 #ifdef MOZ_NSIMIMEINFO_NSACSTRING_
 	nsEmbedCString mMimeType;
 #else
