@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.cpp,v 1.3.4.1 2004/10/10 16:18:26 marco Exp $
+ *  $Id: EphyUtils.cpp,v 1.3.4.3 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -29,7 +29,9 @@
 #include "ephy-embed-single.h"
 
 #include <nsIServiceManager.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIWindowWatcher.h>
 #include <nsIEmbeddingSiteWindow.h>
 #include <nsIWebBrowserChrome.h>
