@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.cpp,v 1.26 2004/08/27 20:39:10 chpe Exp $
+ *  $Id: GlobalHistory.cpp,v 1.26.4.4 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,14 +25,14 @@
 #include "config.h"
 #endif
 
-#include "mozilla-version.h"
-
 #include "ephy-embed-shell.h"
 
 #include "GlobalHistory.h"
 
 #include <nsIURI.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 NS_IMPL_ISUPPORTS2(MozGlobalHistory, nsIGlobalHistory2, nsIBrowserHistory)
 
@@ -45,8 +45,13 @@ MozGlobalHistory::~MozGlobalHistory ()
 {
 }
 
+#ifdef MOZ_NSIBROWSERHISTORY_ADDURI_WITH_REFERRER
+/* void addURI (in nsIURI aURI, in boolean aRedirect, in boolean aToplevel, in nsIURI aReferrer); */
+NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI, PRBool aRedirect, PRBool aToplevel, nsIURI *aReferrer)
+#else
 /* void addURI (in nsIURI aURI, in boolean aRedirect, in boolean aToplevel); */
 NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI, PRBool aRedirect, PRBool aToplevel)
+#endif
 {
 	nsresult rv;
 
@@ -133,7 +138,7 @@ NS_IMETHODIMP MozGlobalHistory::HidePage(nsIURI *aURI)
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-#if (MOZILLA_IS_BRANCH (1, 7) && MOZILLA_CHECK_VERSION3 (1, 7, 3)) || MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 3)
+#ifdef MOZ_NSIGLOBALHISTORY_NSIURIP
 /* void removePage (in nsIURI aURI); */
 NS_IMETHODIMP MozGlobalHistory::RemovePage(nsIURI *aURI)
 {
@@ -179,7 +184,7 @@ NS_IMETHODIMP MozGlobalHistory::GetCount(PRUint32 *aCount)
     return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-#if (MOZILLA_IS_BRANCH (1, 7) && MOZILLA_CHECK_VERSION3 (1, 7, 3)) || MOZILLA_CHECK_VERSION4 (1, 8, MOZILLA_ALPHA, 3)
+#ifdef MOZ_NSIGLOBALHISTORY_NSIURIP
 /* void markPageAsTyped (in AUTF8String aURI) */
 NS_IMETHODIMP MozGlobalHistory::MarkPageAsTyped(nsIURI *aURI)
 {
@@ -192,3 +197,11 @@ NS_IMETHODIMP MozGlobalHistory::MarkPageAsTyped(const char *url)
     return NS_ERROR_NOT_IMPLEMENTED;
 }
 #endif
+
+#ifdef MOZ_NSIBROWSERHISTORY_ADDPAGEWITHDETAILS
+/* void addPageWithDetails (in nsIURI aURI, in wstring aTitle, in long long aLastVisited); */
+NS_IMETHODIMP MozGlobalHistory::AddPageWithDetails(nsIURI *aURI, const PRUnichar *aTitle, PRInt64 aLastVisited)
+{
+	return NS_ERROR_NOT_IMPLEMENTED;
+}
+#endif
