@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.c,v 1.32 2004/06/24 10:03:31 marco Exp $
+ *  $Id: ephy-node.c,v 1.32.4.2 2004/11/01 13:53:38 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,6 +42,7 @@ typedef struct
 	EphyNodeCallback callback;
 	EphyNodeSignalType type;
 	gpointer data;
+	gboolean invalidated;
 } EphyNodeSignalData;
 
 typedef struct
@@ -69,6 +70,8 @@ struct EphyNode
 
 	GHashTable *signals;
 	int signal_id;
+	guint emissions;
+	guint invalidated_signals;
 
 	EphyNodeDb *db;
 };
@@ -98,6 +101,8 @@ callback (long id, EphyNodeSignalData *data, gpointer *dummy)
 	ENESCData *user_data;
 	va_list valist;
 
+	if (data->invalidated) return;
+
 	user_data = (ENESCData *) dummy;
 
 	G_VA_COPY(valist, user_data->valist);
@@ -153,11 +158,21 @@ callback (long id, EphyNodeSignalData *data, gpointer *dummy)
         va_end(valist);
 }
 
+static gboolean
+remove_invalidated_signals (long id,
+			    EphyNodeSignalData *data,
+			    gpointer user_data)
+{
+	return data->invalidated;
+}
+
 static void
 ephy_node_emit_signal (EphyNode *node, EphyNodeSignalType type, ...)
 {
 	ENESCData data;
 
+	++node->emissions;
+
 	va_start (data.valist, type);
 
 	data.type = type;
@@ -167,33 +182,15 @@ ephy_node_emit_signal (EphyNode *node, EphyNodeSignalType type, ...)
 			      &data);
 
 	va_end (data.valist);
-}
 
-static void
-ephy_node_finalize (EphyNode *node)
-{
-	guint i;
-
-	g_hash_table_destroy (node->signals);
-	node->signals = NULL;
-
-	for (i = 0; i < node->properties->len; i++) {
-		GValue *val;
-
-		val = g_ptr_array_index (node->properties, i);
-
-		if (val != NULL) {
-			g_value_unset (val);
-			g_free (val);
-		}
+	if (G_UNLIKELY (--node->emissions == 0 && node->invalidated_signals))
+	{
+		g_hash_table_foreach_remove
+				(node->signals,
+				 (GHRFunc) remove_invalidated_signals,
+				 NULL);
+		node->invalidated_signals = 0;
 	}
-	g_ptr_array_free (node->properties, TRUE);
-
-	g_hash_table_destroy (node->parents);
-
-	g_ptr_array_free (node->children, TRUE);
-
-	g_free (node);
 }
 
 static inline void
@@ -250,13 +247,12 @@ static void
 signal_object_weak_notify (EphyNodeSignalData *signal_data,
                            GObject *where_the_object_was)
 {
+	signal_data->data = NULL;
 	ephy_node_signal_disconnect (signal_data->node, signal_data->id);
 }
 
 static void
-unref_signal_objects (long id,
-	              EphyNodeSignalData *signal_data,
-	              EphyNode *node)
+destroy_signal_data (EphyNodeSignalData *signal_data)
 {
 	if (signal_data->data)
 	{
@@ -264,20 +260,24 @@ unref_signal_objects (long id,
 				     (GWeakNotify)signal_object_weak_notify,
 				     signal_data);
 	}
+        
+        g_free (signal_data);
 }
 
 static void
-ephy_node_dispose (EphyNode *node)
+ephy_node_destroy (EphyNode *node)
 {
 	guint i;
 
 	ephy_node_emit_signal (node, EPHY_NODE_DESTROY);
 
-	/* remove from DAG */
+        /* Remove from parents. */
 	g_hash_table_foreach (node->parents,
 			      (GHFunc) remove_child,
 			      node);
+	g_hash_table_destroy (node->parents);
 
+        /* Remove children. */
 	for (i = 0; i < node->children->len; i++) {
 		EphyNode *child;
 
@@ -285,12 +285,28 @@ ephy_node_dispose (EphyNode *node)
 
 		real_remove_child (node, child, FALSE, TRUE);
 	}
+	g_ptr_array_free (node->children, TRUE);
+        
+        /* Remove signals. */
+	g_hash_table_destroy (node->signals);
 
-	g_hash_table_foreach (node->signals,
-			      (GHFunc) unref_signal_objects,
-			      node);
-
+        /* Remove id. */
 	_ephy_node_db_remove_id (node->db, node->id);
+
+        /* Remove properties. */
+	for (i = 0; i < node->properties->len; i++) {
+		GValue *val;
+
+		val = g_ptr_array_index (node->properties, i);
+
+		if (val != NULL) {
+			g_value_unset (val);
+			g_free (val);
+		}
+	}
+	g_ptr_array_free (node->properties, TRUE);
+
+	g_free (node);
 }
 
 EphyNode *
@@ -328,16 +344,16 @@ ephy_node_new_with_id (EphyNodeDb *db, guint reserved_id)
 
 	node->children = g_ptr_array_new ();
 
-	node->parents = g_hash_table_new_full (int_hash,
-					       int_equal,
-					       NULL,
-					       g_free);
+	node->parents = g_hash_table_new_full
+          (int_hash, int_equal, NULL, g_free);
+
+	node->signals = g_hash_table_new_full
+          (int_hash, int_equal, NULL,
+           (GDestroyNotify)destroy_signal_data);
 
-	node->signals = g_hash_table_new_full (int_hash,
-					       int_equal,
-					       NULL,
-					       g_free);
 	node->signal_id = 0;
+	node->emissions = 0;
+	node->invalidated_signals = 0;
 
 	_ephy_node_db_add_id (db, reserved_id, node);
 
@@ -380,8 +396,7 @@ ephy_node_unref (EphyNode *node)
 	node->ref_count--;
 
 	if (node->ref_count <= 0) {
-		ephy_node_dispose (node);
-		ephy_node_finalize (node);
+		ephy_node_destroy (node);
 	}
 }
 
@@ -1138,6 +1153,8 @@ ephy_node_signal_connect_object (EphyNode *node,
 	int ret;
 
 	g_return_val_if_fail (EPHY_IS_NODE (node), -1);
+	/* FIXME: */
+	g_return_val_if_fail (node->emissions == 0, -1);
 
 	signal_data = g_new0 (EphyNodeSignalData, 1);
 	signal_data->node = node;
@@ -1162,13 +1179,82 @@ ephy_node_signal_connect_object (EphyNode *node,
 	return ret;
 }
 
+static gboolean
+remove_matching_signal_data (gpointer key,
+			     EphyNodeSignalData *signal_data,
+			     EphyNodeSignalData *user_data)
+{
+	return (user_data->data == signal_data->data &&
+		user_data->type == signal_data->type &&
+		user_data->callback == signal_data->callback);           
+}
+
+static void
+invalidate_matching_signal_data (gpointer key,
+				 EphyNodeSignalData *signal_data,
+				 EphyNodeSignalData *user_data)
+{
+	if (user_data->data == signal_data->data &&
+	    user_data->type == signal_data->type &&
+	    user_data->callback == signal_data->callback &&
+	    !signal_data->invalidated)
+	{
+		signal_data->invalidated = TRUE;
+		++signal_data->node->invalidated_signals;
+	}
+}
+
+guint
+ephy_node_signal_disconnect_object (EphyNode *node,
+                                    EphyNodeSignalType type,
+                                    EphyNodeCallback callback,
+                                    GObject *object)
+{
+        EphyNodeSignalData user_data;
+
+	g_return_val_if_fail (EPHY_IS_NODE (node), 0);
+
+	user_data.callback = callback;
+	user_data.type = type;
+	user_data.data = object;
+
+	if (G_LIKELY (node->emissions == 0))
+	{
+		return g_hash_table_foreach_remove (node->signals,
+						    (GHRFunc) remove_matching_signal_data,
+						    &user_data);
+	}
+	else
+	{
+		g_hash_table_foreach (node->signals,
+				      (GHFunc) invalidate_matching_signal_data,
+				      &user_data);
+		return 0;
+	}
+}
+
 void
 ephy_node_signal_disconnect (EphyNode *node,
 			     int signal_id)
 {
 	g_return_if_fail (EPHY_IS_NODE (node));
+	g_return_if_fail (signal_id != -1);
 
-	g_hash_table_remove (node->signals,
-			     GINT_TO_POINTER (signal_id));
+	if (G_LIKELY (node->emissions == 0))
+	{
+		g_hash_table_remove (node->signals,
+				     GINT_TO_POINTER (signal_id));
+	}
+	else
+	{
+		EphyNodeSignalData *data;
+
+		data = g_hash_table_lookup (node->signals,
+					    GINT_TO_POINTER (signal_id));
+		g_return_if_fail (data != NULL);
+		g_return_if_fail (!data->invalidated);
+
+		data->invalidated = TRUE;
+		node->invalidated_signals++;
+	}
 }
-
