@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.143.4.1 2004/10/08 12:17:26 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.143.4.3 2004/11/07 19:57:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +47,6 @@
 #include <string.h>
 
 #include "ephy-bookmarks-editor.h"
-#include "ephy-bookmark-properties.h"
 #include "ephy-bookmarks-import.h"
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
@@ -149,7 +148,6 @@ struct EphyBookmarksEditorPrivate
 	GtkActionGroup *action_group;
 	int priority_col;
 	EphyBookmarksBarModel *tb_model;
-	GHashTable *props_dialogs;
 
 	GtkTreeViewColumn *title_col;
 	GtkTreeViewColumn *address_col;
@@ -479,31 +477,11 @@ cmd_delete (GtkAction *action,
 }
 
 static void
-prop_dialog_destroy_cb (GtkWidget *dialog, EphyBookmarksEditor *editor)
+show_properties_dialog (EphyBookmarksEditor *editor,
+			EphyNode *bookmark)
 {
-	EphyNode *node;
-
-	node = ephy_bookmark_properties_get_node (EPHY_BOOKMARK_PROPERTIES (dialog));
-	g_hash_table_remove (editor->priv->props_dialogs, node);
-}
-
-static void
-show_properties_dialog (EphyBookmarksEditor *editor, EphyNode *node)
-{
-	GtkWidget *dialog;
-
-	dialog = g_hash_table_lookup (editor->priv->props_dialogs, node);
-
-	if (!dialog)
-	{
-		dialog = ephy_bookmark_properties_new
-			(editor->priv->bookmarks, node, GTK_WINDOW (editor));
-		g_signal_connect (dialog, "destroy",
-				  G_CALLBACK (prop_dialog_destroy_cb), editor);
-		g_hash_table_insert (editor->priv->props_dialogs, node, dialog);
-	}
-
-	gtk_window_present (GTK_WINDOW (dialog));
+	ephy_bookmarks_show_bookmark_properties
+		(editor->priv->bookmarks, bookmark, GTK_WIDGET (editor));
 }
 
 static void
@@ -928,8 +906,6 @@ ephy_bookmarks_editor_finalize (GObject *object)
                          (gpointer *)&editor->priv->window);
 	}
 
-	g_hash_table_destroy (editor->priv->props_dialogs);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -1137,8 +1113,7 @@ ephy_bookmarks_editor_show_popup_cb (GtkWidget *view,
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					    "/EphyBookmarkEditorPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
 
 	return TRUE;
 }
@@ -1230,8 +1205,7 @@ keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					   "/EphyBookmarkKeywordPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
 
 	return TRUE;
 }
@@ -1690,8 +1664,6 @@ ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 {
 	editor->priv = EPHY_BOOKMARKS_EDITOR_GET_PRIVATE (editor);
 
-	editor->priv->props_dialogs = g_hash_table_new (g_direct_hash,
-                                                        g_direct_equal);
 	editor->priv->tb_model = EPHY_BOOKMARKSBAR_MODEL
 		(ephy_bookmarks_get_toolbars_model
 			(ephy_shell_get_bookmarks (ephy_shell)));
