@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.71.4.2 2004/10/08 12:16:39 marco Exp $
+ *  $Id: ephy-history-window.c,v 1.71.4.6 2004/11/09 00:58:14 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -842,8 +842,7 @@ ephy_history_window_show_popup_cb (GtkWidget *view,
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					    "/EphyHistoryWindowPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
 
 	return TRUE;
 }
@@ -879,38 +878,57 @@ add_by_site_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level
 		 level);
 }
 
-#define SEC_PER_DAY (60 * 60 * 24)
-
 static void
-add_by_date_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level,
+add_by_date_filter (EphyHistoryWindow *editor,
+		    EphyNodeFilter *filter,
+		    int level,
 		    EphyNode *equals)
 {
-	GTime now, cmp_time, days;
-	int time_range;
-
-	/* FIXME this is probably wrong for timezones */
+	time_t now, midnight, cmp_time = 0;
+	struct tm btime;
+	int time_range, days = 0;
 
 	time_range = gtk_combo_box_get_active
 		(GTK_COMBO_BOX (editor->priv->time_combo));
 
+	/* no need to setup a new filter */
+	if (time_range == TIME_EVER) return;
+
 	now = time (NULL);
-	days = now / SEC_PER_DAY;
+	if (localtime_r (&now, &btime) == NULL) return;
+
+	/* get start of day */
+	btime.tm_sec = 0;
+	btime.tm_min = 0;
+	btime.tm_hour = 0;
+	midnight = mktime (&btime);
 
 	switch (time_range)
 	{
-		case TIME_EVER:
-			return;
-		case TIME_TODAY:
-			break;
-		case TIME_LAST_TWO_DAYS:
-			days -= 1;
-			break;
 		case TIME_LAST_THREE_DAYS:
-			days -= 2;
+			days++;
+			/* fall-through */
+		case TIME_LAST_TWO_DAYS:
+			days++;
+			/* fall-through */
+		case TIME_TODAY:
+			cmp_time = midnight;
+			break;
+		default:
+			g_return_if_reached ();
 			break;
 	}
 
-	cmp_time = days * SEC_PER_DAY;
+	while (--days >= 0)
+	{
+		/* subtract 1 day */
+		cmp_time -= 43200;
+		localtime_r (&cmp_time, &btime);
+		btime.tm_sec = 0;
+		btime.tm_min = 0;
+		btime.tm_hour = 0;
+		cmp_time = mktime (&btime);
+	}
 
 	ephy_node_filter_add_expression
 		(filter, ephy_node_filter_expression_new
