@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.h,v 1.10 2004/08/06 14:34:07 chpe Exp $
+ *  $Id: ephy-notebook.h,v 1.10.4.1 2004/10/25 13:41:27 chpe Exp $
  */
 
 #ifndef EPHY_NOTEBOOK_H
@@ -54,15 +54,15 @@ struct EphyNotebookClass
         GtkNotebookClass parent_class;
 
 	/* Signals */
-	void (* tab_added)      (EphyNotebook *notebook,
-				 EphyTab *tab);
-	void (* tab_removed)    (EphyNotebook *notebook,
-				 EphyTab *tab);
-	void (* tab_detached)   (EphyNotebook *notebook,
-				 EphyTab *tab);
-	void (* tabs_reordered) (EphyNotebook *notebook);
-	void (* tab_delete)	(EphyNotebook *notebook,
-				 EphyTab *tab);
+	void	 (* tab_added)      (EphyNotebook *notebook,
+				     EphyTab *tab);
+	void	 (* tab_removed)    (EphyNotebook *notebook,
+				     EphyTab *tab);
+	void	 (* tab_detached)   (EphyNotebook *notebook,
+				     EphyTab *tab);
+	void	 (* tabs_reordered) (EphyNotebook *notebook);
+	gboolean (* tab_delete)	    (EphyNotebook *notebook,
+				     EphyTab *tab);
 };
 
 GType		ephy_notebook_get_type		(void);
