@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.15 2004/04/05 18:06:14 chpe Exp $
+ *  $Id: ephy-session.c,v 1.20.4.4 2004/11/11 17:57:51 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +38,9 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
+#include <errno.h>
 #include <string.h>
+#include <stdlib.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
@@ -54,7 +56,9 @@
 struct EphySessionPrivate
 {
 	GList *windows;
+	GList *tool_windows;
 	GtkWidget *resume_dialog;
+	gboolean resuming;
 };
 
 #define BOOKMARKS_EDITOR_ID	"BookmarksEditor"
@@ -267,7 +271,9 @@ ephy_session_init (EphySession *session)
 	LOG ("EphySession initialising")
 
 	session->priv->windows = NULL;
+	session->priv->tool_windows = NULL;
 	session->priv->resume_dialog = NULL;
+	session->priv->resuming = FALSE;
 
 	ensure_session_directory ();
 }
@@ -280,6 +286,8 @@ ephy_session_dispose (GObject *object)
 	LOG ("EphySession disposing")
 
 	session_delete (session, SESSION_CRASHED);
+
+	parent_class->dispose (object);
 }
 
 static void
@@ -289,7 +297,9 @@ ephy_session_finalize (GObject *object)
 
 	LOG ("EphySession finalising")
 
+	/* FIXME: those should be NULL already!? */
 	g_list_free (session->priv->windows);
+	g_list_free (session->priv->tool_windows);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -308,6 +318,7 @@ ephy_session_set_property (GObject *object,
 			   GParamSpec *pspec)
 {
 	/* no writeable properties */
+	g_return_if_reached ();
 }
 
 static void
@@ -346,8 +357,8 @@ ephy_session_class_init (EphySessionClass *class)
 		 g_param_spec_object ("active-window",
 		 		      "Active Window",
 		 		      "The active window",
-				       EPHY_TYPE_WINDOW,
-				       G_PARAM_READABLE));
+				      EPHY_TYPE_WINDOW,
+				      G_PARAM_READABLE));
 
 	g_type_class_add_private (object_class, sizeof (EphySessionPrivate));
 }
@@ -451,7 +462,10 @@ ephy_session_autoresume (EphySession *session)
 	if (g_file_test (saved_session, G_FILE_TEST_EXISTS)
 	    && offer_to_resume (session))
 	{
+		session->priv->resuming = TRUE;
 		retval = ephy_session_load (session, saved_session);
+		session->priv->resuming = FALSE;
+		ephy_session_save (session, SESSION_CRASHED);
 	}
 
 	g_free (saved_session);
@@ -466,12 +480,20 @@ ephy_session_close (EphySession *session)
 
 	LOG ("ephy_session_close")
 
+	/* we have to ref the shell or else we may get finalised between
+	 * destroying the windows and destroying the tool windows
+	 */
+	g_object_ref (ephy_shell);
+
 	windows	= ephy_session_get_windows (session);
-
-	/* close all windows */
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
-
 	g_list_free (windows);
+
+	windows = g_list_copy (session->priv->tool_windows);
+	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
+	g_list_free (windows);	
+
+	g_object_unref (ephy_shell);
 }
 
 static int
@@ -482,12 +504,12 @@ write_tab (xmlTextWriterPtr writer,
 	char *location;
 	int ret;
 
-	ret = xmlTextWriterStartElement (writer, "embed");
+	ret = xmlTextWriterStartElement (writer, (xmlChar *) "embed");
 	if (ret < 0) return ret;
 
 	embed = ephy_tab_get_embed (tab);
 	location = ephy_embed_get_location (embed, TRUE);
-	ret = xmlTextWriterWriteAttribute (writer, "url", location);
+	ret = xmlTextWriterWriteAttribute (writer, (xmlChar *) "url", (xmlChar *) location);
 	g_free (location);
 	if (ret < 0) return ret;
 
@@ -499,7 +521,7 @@ static int
 write_window_geometry (xmlTextWriterPtr writer,
 		       GtkWindow *window)
 {
-	int x = 0, y = 0, width = 0, height = 0;
+	int x = 0, y = 0, width = -1, height = -1;
 	int ret;
 
 	/* get window geometry */
@@ -507,30 +529,43 @@ write_window_geometry (xmlTextWriterPtr writer,
 	gtk_window_get_position (window, &x, &y);
 
 	/* set window properties */
-	ret = xmlTextWriterWriteFormatAttribute (writer, "x", "%d", x);
+	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *) "x", "%d", x);
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteFormatAttribute (writer, "y", "%d", y);
+	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *) "y", "%d", y);
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteFormatAttribute (writer, "width", "%d", width);
+	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *) "width", "%d", width);
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteFormatAttribute (writer, "height", "%d", height);
+	ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *) "height", "%d", height);
 	return ret;
 }
 
 static int
 write_tool_window (xmlTextWriterPtr writer,
-		   GtkWindow *window,
-		   xmlChar *id)
+		   GtkWindow *window)
 {
+	const xmlChar *id;
 	int ret;
 
-	ret = xmlTextWriterStartElement (writer, "toolwindow");
+	if (EPHY_IS_BOOKMARKS_EDITOR (window))
+	{
+		id = (const xmlChar *) BOOKMARKS_EDITOR_ID;
+	}
+	else if (EPHY_IS_HISTORY_WINDOW (window))
+	{
+		id = (const xmlChar *) HISTORY_WINDOW_ID;
+	}
+	else
+	{
+		g_return_val_if_reached (-1);
+	}
+
+	ret = xmlTextWriterStartElement (writer, (const xmlChar *) "toolwindow");
 	if (ret < 0) return ret;
 
-	ret = xmlTextWriterWriteAttribute (writer, "id", id);
+	ret = xmlTextWriterWriteAttribute (writer, (const xmlChar *) "id", id);
 	if (ret < 0) return ret;
 
 	ret = write_window_geometry (writer, window);
@@ -554,7 +589,7 @@ write_ephy_window (xmlTextWriterPtr writer,
 	 */
 	if (tabs == NULL) return 0;
 
-	ret = xmlTextWriterStartElement (writer, "window");
+	ret = xmlTextWriterStartElement (writer, (xmlChar *) "window");
 	if (ret < 0) return ret;
 
 	ret = write_window_geometry (writer, GTK_WINDOW (window));
@@ -582,9 +617,14 @@ ephy_session_save (EphySession *session,
 	char *save_to, *tmp_file;
 	int ret;
 
+	if (session->priv->resuming)
+	{
+		return TRUE;
+	}
+
 	LOG ("ephy_sesion_save %s", filename)
 
-	if (session->priv->windows == NULL)
+	if (session->priv->windows == NULL && session->priv->tool_windows == NULL)
 	{
 		session_delete (session, filename);
 		return TRUE;
@@ -606,7 +646,7 @@ ephy_session_save (EphySession *session,
 	ret = xmlTextWriterSetIndent (writer, 1);
 	if (ret < 0) goto out;
 
-	ret = xmlTextWriterSetIndentString (writer, "  ");
+	ret = xmlTextWriterSetIndentString (writer, (const xmlChar *) "  ");
 	if (ret < 0) goto out;
 
 	START_PROFILER ("Saving session")
@@ -615,27 +655,19 @@ ephy_session_save (EphySession *session,
 	if (ret < 0) goto out;
 
 	/* create and set the root node for the session */
-	ret = xmlTextWriterStartElement (writer, "session");
+	ret = xmlTextWriterStartElement (writer, (const xmlChar *) "session");
 	if (ret < 0) goto out;
 
-	/* iterate through all the windows */
-	for (w = session->priv->windows; w != NULL; w = w->next)
+	/* iterate through all the windows */	
+	for (w = session->priv->windows; w != NULL && ret >= 0; w = w->next)
 	{
-		GtkWindow *window = w->data;
-	
-		if (EPHY_IS_WINDOW (window))
-		{
-			ret = write_ephy_window (writer, EPHY_WINDOW (window));
-		}
-		else if (EPHY_IS_BOOKMARKS_EDITOR (window))
-		{
-			ret = write_tool_window (writer, window, BOOKMARKS_EDITOR_ID);
-		}
-		else if (EPHY_IS_HISTORY_WINDOW (window))
-		{
-			ret = write_tool_window (writer, window, HISTORY_WINDOW_ID);
-		}
-		if (ret < 0) break;
+		ret = write_ephy_window (writer, EPHY_WINDOW (w->data));
+	}
+	if (ret < 0) goto out;
+
+	for (w = session->priv->tool_windows; w != NULL && ret >= 0; w = w->next)
+	{
+		ret = write_tool_window (writer, GTK_WINDOW (w->data));
 	}
 	if (ret < 0) goto out;
 
@@ -668,15 +700,15 @@ parse_embed (xmlNodePtr child, EphyWindow *window)
 {
 	while (child != NULL)
 	{
-		if (strcmp (child->name, "embed") == 0)
+		if (strcmp ((char *) child->name, "embed") == 0)
 		{
 			xmlChar *url;
 
 			g_return_if_fail (window != NULL);
 
-			url = xmlGetProp (child, "url");
+			url = xmlGetProp (child, (const xmlChar *) "url");
 
-			ephy_shell_new_tab (ephy_shell, window, NULL, url,
+			ephy_shell_new_tab (ephy_shell, window, NULL, (char *) url,
 					    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
 					    EPHY_NEW_TAB_OPEN_PAGE |
 					    EPHY_NEW_TAB_APPEND_LAST);
@@ -688,6 +720,55 @@ parse_embed (xmlNodePtr child, EphyWindow *window)
 	}
 }
 
+static gboolean
+int_from_string (const char *string,
+		 int *retval)
+{
+	char *tail = NULL;
+	long int val;
+	gboolean success = FALSE;
+
+	errno = 0;
+	val = strtol (string, &tail, 0);
+
+	if (errno == 0 && tail != NULL && tail[0] == '\0')
+	{
+		*retval = (int) val;
+		success = TRUE;
+	}
+
+	return success;
+}
+
+static void
+restore_geometry (GtkWindow *window,
+		  xmlNodePtr node)
+{
+	xmlChar *tmp;
+	int x = 0, y = 0, width = -1, height = -1;
+	gboolean success = TRUE;
+
+	g_return_if_fail (window != NULL);
+
+	tmp = xmlGetProp (node, (xmlChar *) "x");
+	success &= int_from_string ((char *) tmp, &x);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "y");
+	success &= int_from_string ((char *) tmp, &y);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "width");
+	success &= int_from_string ((char *) tmp, &width);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "height");
+	success &= int_from_string ((char *) tmp, &height);
+	xmlFree (tmp);
+
+	if (success)
+	{
+		gtk_window_move (window, x, y);
+		gtk_window_set_default_size (window, width, height);
+	}
+}
 /*
  * ephy_session_load:
  * @session: a #EphySession
@@ -725,54 +806,36 @@ ephy_session_load (EphySession *session,
 
 	while (child != NULL)
 	{
-		if (xmlStrEqual (child->name, "window"))
+		if (xmlStrEqual (child->name, (const xmlChar *) "window"))
 		{
 			widget = GTK_WIDGET (ephy_window_new ());
+			restore_geometry (GTK_WINDOW (widget), child);
 			parse_embed (child->children, EPHY_WINDOW (widget));
+			gtk_window_present (GTK_WINDOW (widget));
 		}
-		else if (xmlStrEqual (child->name, "toolwindow"))
+		else if (xmlStrEqual (child->name, (const xmlChar *) "toolwindow"))
 		{
 			xmlChar *id;
 
-			id = xmlGetProp (child, "id");
+			id = xmlGetProp (child, (const xmlChar *) "id");
 
-			if (id && xmlStrEqual (BOOKMARKS_EDITOR_ID, id))
+			if (id && xmlStrEqual ((const xmlChar *) BOOKMARKS_EDITOR_ID, id))
 			{
 				if (!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING))
 				{
 					widget = ephy_shell_get_bookmarks_editor (ephy_shell);
 				}
 			}
-			else if (id && xmlStrEqual (HISTORY_WINDOW_ID, id))
+			else if (id && xmlStrEqual ((const xmlChar *) HISTORY_WINDOW_ID, id))
 			{
-				if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY))
+				if (!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY))
 				{
 					widget = ephy_shell_get_history_window (ephy_shell);
 				}
 			}
-		}
 
-		if (widget)
-		{
-			xmlChar *tmp;
-			gulong x = 0, y = 0, width = 0, height = 0;
-
-			tmp = xmlGetProp (child, "x");
-			ephy_string_to_int (tmp, &x);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, "y");
-			ephy_string_to_int (tmp, &y);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, "width");
-			ephy_string_to_int (tmp, &width);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, "height");
-			ephy_string_to_int (tmp, &height);
-			xmlFree (tmp);
-			gtk_window_move (GTK_WINDOW (widget), x, y);
-			gtk_window_set_default_size (GTK_WINDOW (widget),
-				                     width, height);
-			gtk_widget_show (widget);
+			restore_geometry (GTK_WINDOW (widget), child);
+			gtk_window_present (GTK_WINDOW (widget));
 		}
 
 		child = child->next;
@@ -780,9 +843,15 @@ ephy_session_load (EphySession *session,
 
 	xmlFreeDoc (doc);
 
-	return (session->priv->windows != NULL);
+	return (session->priv->windows != NULL || session->priv->tool_windows != NULL);
 }
 
+/**
+ * ephy_session_get_windows:
+ * @ephy_session: the #EphySession
+ *
+ * Returns: the list of open #EphyWindow:s.
+ **/
 GList *
 ephy_session_get_windows (EphySession *session)
 {
@@ -803,9 +872,10 @@ void
 ephy_session_add_window (EphySession *session,
 			 GtkWindow *window)
 {
-	LOG ("ephy_session_add_window")
+	LOG ("ephy_session_add_window %p", window)
 
-	session->priv->windows = g_list_append (session->priv->windows, window);
+	session->priv->tool_windows =
+		g_list_append (session->priv->tool_windows, window);
 
 	ephy_session_save (session, SESSION_CRASHED);
 }
@@ -813,7 +883,7 @@ ephy_session_add_window (EphySession *session,
 /**
  * ephy_session_remove_window:
  * @session: a #EphySession.
- * @window: a #GtkWindow. This is either the bookmarks editor or the
+ * @window: a #GtkWindow, which must be either the bookmarks editor or the
  * history window.
  *
  * Remove a tool window from the session.
@@ -822,9 +892,10 @@ void
 ephy_session_remove_window (EphySession *session,
 			    GtkWindow *window)
 {
-	LOG ("ephy_session_remove_window")
+	LOG ("ephy_session_remove_window %p", window)
 
-	session->priv->windows = g_list_remove (session->priv->windows, window);
+	session->priv->tool_windows =
+		g_list_remove (session->priv->tool_windows, window);
 
 	ephy_session_save (session, SESSION_CRASHED);
 }
@@ -842,19 +913,15 @@ ephy_session_remove_window (EphySession *session,
 EphyWindow *
 ephy_session_get_active_window (EphySession *session)
 {
-	GList *l;
-	EphyWindow *window = NULL;
+	GList *first;
 
 	g_return_val_if_fail (EPHY_IS_SESSION (session), NULL);
 
-	for (l = session->priv->windows; l != NULL; l = l->next)
+	first = session->priv->windows;
+	if (first != NULL)
 	{
-		if (EPHY_IS_WINDOW (l->data))
-		{
-			window = EPHY_WINDOW (l->data);
-			break;
-		}
+		return EPHY_WINDOW (first->data);
 	}
 
-	return window;
+	return NULL;
 }
