@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.91.4.2 2004/10/16 13:52:16 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.91.4.3 2004/11/25 23:04:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -587,7 +587,7 @@ ephy_shell_new_tab (EphyShell *shell,
 	embed = ephy_tab_get_embed (tab);
 
 	ephy_window_add_tab (window, tab, position, jump_to);
-	gtk_window_present (GTK_WINDOW (window));
+	gtk_widget_show (GTK_WIDGET (window));
 
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
