@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.206.4.6 2004/10/08 21:12:09 chpe Exp $
+ *  $Id: ephy-window.c,v 1.206.4.14 2004/11/07 20:28:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1528,10 +1528,17 @@ static void
 popup_menu_at_coords (GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 		      gpointer user_data)
 {
-	EphyEmbedEvent *event = (EphyEmbedEvent *) user_data;
+	GtkWidget *window = GTK_WIDGET (user_data);
+	EphyEmbedEvent *event;
+
+	event = g_object_get_data (G_OBJECT (window), "context_event");
+	g_return_if_fail (event != NULL);
 
 	ephy_embed_event_get_coords (event, x, y);
 
+	/* FIXME: better position the popup within the window bounds? */
+	ephy_gui_sanitise_popup_position (menu, window, x, y);
+
 	*push_in = TRUE;
 }
 
@@ -1623,8 +1630,9 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	if (type == EPHY_EMBED_EVENT_KEY)
 	{
 		gtk_menu_popup (GTK_MENU (widget), NULL, NULL,
-				popup_menu_at_coords, event, 2,
+				popup_menu_at_coords, window, 0,
 				gtk_get_current_event_time ());
+		gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), FALSE);
 	}
 	else
 	{
@@ -1817,11 +1825,39 @@ update_tabs_menu_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", detach, NULL);
 }
 
+static gboolean
+modal_alert_cb (EphyEmbed *embed,
+		EphyWindow *window)
+{
+	EphyTab *tab;
+	char *address;
+
+	tab = ephy_tab_for_embed (embed);
+	g_return_val_if_fail (tab != NULL, FALSE);
+
+	/* switch the window to the tab, and bring the window to the foreground
+	 * (since the alert is modal, the user won't be able to do anything
+	 * with his current window anyway :|)
+	 */
+	ephy_window_jump_to_tab (window, tab);
+	gtk_window_present (GTK_WINDOW (window));
+
+	/* make sure the location entry shows the real URL of the tab's page */
+	address = ephy_embed_get_location (embed, TRUE);
+	toolbar_set_location (window->priv->toolbar, address);
+	g_free (address);
+
+	/* don't suppress alert */
+	return FALSE;
+}
+
 static void
 tab_added_cb (EphyNotebook *notebook,
 	      EphyTab *tab,
 	      EphyWindow *window)
 {
+	EphyEmbed *embed;
+
         g_return_if_fail (EPHY_IS_TAB (tab));
 
 	window->priv->num_tabs++;
@@ -1830,6 +1866,12 @@ tab_added_cb (EphyNotebook *notebook,
 
 	g_signal_connect_object (G_OBJECT (tab), "notify::visible",
 				 G_CALLBACK (sync_tab_visibility), window, 0);
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (embed != NULL);
+
+	g_signal_connect_after (embed, "ge-modal-alert",
+				G_CALLBACK (modal_alert_cb), window);
 }
 
 static void
@@ -1837,6 +1879,8 @@ tab_removed_cb (EphyNotebook *notebook,
 		EphyTab *tab,
 		EphyWindow *window)
 {
+	EphyEmbed *embed;
+
         g_return_if_fail (EPHY_IS_TAB (tab));
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (tab),
@@ -1849,6 +1893,12 @@ tab_removed_cb (EphyNotebook *notebook,
 	{
 		update_tabs_menu_sensitivity (window);
 	}
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (embed != NULL);
+
+	g_signal_handlers_disconnect_by_func
+		(embed, G_CALLBACK (modal_alert_cb), window);
 }
 
 static void
@@ -2204,6 +2254,9 @@ ephy_window_init (EphyWindow *window)
 	window->priv->toolbar = toolbar_new (window);
 	window->priv->bookmarksbar = ephy_bookmarksbar_new (window);
 
+	g_signal_connect_swapped (window->priv->toolbar, "activation-finished",
+				  G_CALLBACK (sync_chromes_visibility), window);
+
 	/* forward the toolbar's action_request signal to the bookmarks toolbar,
 	 * so the user can also have bookmarks on the normal toolbar
 	 */
@@ -2614,7 +2667,7 @@ ephy_window_activate_location (EphyWindow *window)
  *
  * Shows @widget if it is hidden.
  **/
-void
+static void
 ephy_window_show (GtkWidget *widget)
 {
 	EphyWindow *window = EPHY_WINDOW(widget);
@@ -2652,7 +2705,6 @@ EphyTab *
 ephy_window_get_active_tab (EphyWindow *window)
 {
 	g_return_val_if_fail (EPHY_IS_WINDOW (window), NULL);
-	g_return_val_if_fail (EPHY_IS_TAB (window->priv->active_tab), NULL);
 
 	return window->priv->active_tab;
 }
