@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: toolbar.h,v 1.18 2004/06/10 19:05:53 chpe Exp $
+ *  $Id: toolbar.h,v 1.18.4.1 2004/11/01 15:14:20 chpe Exp $
  */
 
 #ifndef TOOLBAR_H
@@ -53,6 +53,9 @@ struct Toolbar
 struct ToolbarClass
 {
         EggEditableToolbarClass parent_class;
+
+	/* Signals */
+	void (* activation_finished)	(Toolbar *toolbar);
 };
 
 GType         toolbar_get_type			(void);
